@@ -24,22 +24,28 @@ cds_list_jobs <- function(job_id = NULL, status = NULL, limit = 50,
     status <- match.arg(
       status, c("accepted", "running", "successful", "failed", "rejected"))
   
-  result <-
-    .base_url |>
-    paste("retrieve/v1/jobs", job_id, sep = "/") |>
-    httr2::url_modify_query(status = status, limit = limit) |>
-    .execute_request(token)
+  job_info <- function(id, stat, lim) {
+    result <-
+      .base_url |>
+      paste("retrieve/v1/jobs", id, sep = "/") |>
+      httr2::url_modify_query(status = stat, limit = lim) |>
+      .execute_request(token)
+    
+    meta <- result$metadata
+    result <-
+      if ("jobs" %in% names(result)) {
+        result$jobs |>
+          .simplify()
+      } else {
+        result |> list() |> .simplify()
+      }
+    attributes(result)$MetaList <- meta
+    result
+  }
   
-  meta <- result$metadata
-  result <-
-    if ("jobs" %in% names(result)) {
-      result$jobs |>
-        .simplify()
-    } else {
-      result |> list() |> .simplify()
-    }
-  attributes(result)$MetaList <- meta
-  result
+  if (is.null(job_id)) job_info(NULL, status, limit) else
+    lapply(job_id, job_info, status, limit) |>
+      dplyr::bind_rows()
 }
 
 #' Delete/cancel jobs submitted to the Climate Data Service
@@ -74,3 +80,44 @@ cds_delete_job <- function(job_id, ..., token = cds_get_token()) {
     .execute_request(token, "POST", list(job_ids = as.list(job_id)))
   result$jobs |> .simplify()
 }
+
+#' Get the results for a submitted job
+#' 
+#' When a job is completed, you can get its results (i.e. download link)
+#' by calling this function.
+#' @param job_id Hexadecimal code used as identifier of a job. Identifies the job
+#' for which to obtain the results.
+#' @param ... Ignored
+#' @inheritParams cds_check_authentication
+#' @returns Returns a `data.frame` with information about the requested job.
+#' @examples
+#' if (interactive() && cds_token_works()) {
+#'   job <- cds_submit_job(
+#'       dataset        = "reanalysis-era5-pressure-levels",
+#'       variable       = "geopotential",
+#'       product_type   = "reanalysis",
+#'       area           = c(n = 55, w = -1, s = 50, e = 10),
+#'       year           = "2024",
+#'       month          = "03",
+#'       day            = "01",
+#'       pressure_level = "1000",
+#'       data_format    = "netcdf"
+#'     )
+#'   cds_job_results(job$jobID)
+#' }
+#' @include helpers.R
+#' @export
+cds_job_results <- function(job_id, ..., token = cds_get_token()) {
+  result <-
+    .base_url |>
+    paste("retrieve/v1/jobs/%s/results", sep = "/") |>
+    sprintf(job_id) |>
+    lapply(
+      .execute_request, token, "GET", list(job_ids = as.list(job_id))) |>
+    lapply(`[[`, "asset") |>
+    lapply(`[[`, "value") |>
+    lapply(dplyr::as_tibble) |>
+    lapply(\(x) dplyr::bind_cols(dplyr::tibble(job_id = NA), x)) |>
+    dplyr::bind_rows() |>
+    dplyr::mutate(job_id = .env$job_id)
+}
